@@ -180,11 +180,12 @@ def read_mol_smiles(mol_dict: Settings) -> Optional[Molecule]:
         print_exception('read_mol_smiles', mol_dict.name, ex)
 
 
-def _from_smiles(smiles: str) -> Molecule:
-    sanitize = Chem.SanitizeFlags.SANITIZE_ALL ^ Chem.SanitizeFlags.SANITIZE_ADJUSTHS
-    _rdmol = Chem.MolFromSmiles(smiles, sanitize=False)
-    Chem.rdmolops.SanitizeMol(_rdmol, sanitizeOps=sanitize)
+SMILES_PARAMS = Chem.SmilesParserParams()
+SMILES_PARAMS.removeHs = False
 
+
+def _from_smiles(smiles: str) -> Molecule:
+    _rdmol = Chem.MolFromSmiles(smiles, params=SMILES_PARAMS)
     rdmol = Chem.AddHs(_rdmol)
     rdmol.SetProp('smiles', smiles)
     return molkit.get_conformations(rdmol, 1, None, None, rms=0.1)
@@ -328,22 +329,16 @@ def canonicalize_mol(mol: Molecule, inplace: bool = True) -> Optional[Molecule]:
 
 def get_charge_dict() -> Dict[str, int]:
     """Create a dictionary of elements and their formal atomic charge."""
-    # Create a list of atomic charges and elements
-    charges = (1, 2, -3, -2, -1, 2)
-    elements = (
-        ('Li', 'Na', 'K', 'Rb', 'Cs'),      # Group 1: Alkali metals
-        ('Be', 'Mg', 'Ca', 'Sr', 'Ba'),     # Group 2: Alkaline earth metals
-        ('N', 'P', 'As', 'Sb', 'Bi'),       # Group 15: pnictogens
-        ('O', 'S', 'Se', 'Te', 'Po'),       # Group 16: Chalcogens
-        ('H', 'F', 'Cl', 'Br', 'I', 'At'),  # Group 17: Halogens
-        ('Cd', 'Pb')                        # Misc
-    )
-
-    # Combine the elements and atomic charges into a dictionary
-    values = itertools.chain.from_iterable([i] * len(j) for i, j in zip(charges, elements))
-    keys = itertools.chain(*elements)
-
-    return dict(zip(keys, values))
+    elements = [
+        (1, ['Li', 'Na', 'K', 'Rb', 'Cs']),         # Group 1: Alkali metals
+        (2, ['Be', 'Mg', 'Ca', 'Sr', 'Ba']),        # Group 2: Alkaline earth metals
+        (-3, ['N', 'P', 'As', 'Sb', 'Bi']),         # Group 15: pnictogens
+        (-2, ['O', 'S', 'Se', 'Te', 'Po']),         # Group 16: Chalcogens
+        (-1, ['H', 'F', 'Cl', 'Br', 'I', 'At']),    # Group 17: Halogens
+        (2, ['Cd', 'Pb']),                          # Misc 2+
+        (3, ['In']),                                # Misc 3+
+    ]
+    return {at: q for q, at_list in elements for at in at_list}
 
 
 #: A dictionary with default atomic charges
@@ -359,7 +354,7 @@ def set_mol_prop(mol: Molecule, mol_dict: Settings) -> None:
         residue_name = 'LIG'
         mol.properties.name = mol_dict.name
 
-    mol.properties.dummies = mol_dict.indices
+    mol.properties.dummies = mol_dict.get("indices")
     mol.properties.path = mol_dict.path
     mol.properties.job_path = []
 
